/**
 * @packageDocumentation
 * @module String
 */
import { Observable, ObservableInput } from 'rxjs';
import { ArrayOrSet } from '../types/array-set';
/**
 * Returns an Observable that emits strings from any an argument list of strings or  supported Observable, Promise or
 * Array-like source
 *
 * @category Create
 *
 * @remarks This operator is a type-safe {@link https://rxjs.dev/api/index/function/from|from} and will emit only
 * strings, also unlike `from` a single string is not converted into an array-like.
 *
 * @param args Argument list, Observable input, Promise or Array of strings
 *
 * @example
 * Return a reversed string from an argument list of strings
 * ```ts
 * fromString('RxJS', 'Ninja').pipe(reverse()).subscribe();
 * ```
 * Output: `'SJxR', 'ajniN'`
 *
 * @example
 * Return a reversed string from an array list of strings
 * ```ts
 * fromString(['RxJS', 'Ninja']).pipe(reverse()).subscribe();
 * ```
 * Output: `'SJxR', 'ajniN'`
 *
 * @example
 * Return a reversed string from an Observable array list of strings
 * ```ts
 * fromString(of(['RxJS', 'Ninja'])).pipe(reverse()).subscribe();
 * ```
 * Output: `'SJxR', 'ajniN'`
 *
 * @returns Observable that emits a string
 */
export declare function fromString<A extends ObservableInput<ArrayOrSet<string> | string> | PromiseLike<ArrayOrSet<string> | string> | ArrayOrSet<string> | string>(...args: A[]): Observable<string>;
